@@ -70,7 +70,8 @@ define ([
             },
 
             // actions triggered from employee menu
-            "empProfileUpdate": empLib.empProfile,
+            "myProfile": empLib.myProfile,
+            "empProfileUpdate": empLib.empProfileUpdate,
             "passChangePending": empLib.passChangePending,
             "saveChangedPassword": empLib.mainEmpl,
             "newEmplSubmit": empLib.newEmplSubmit,
