@@ -98,6 +98,24 @@ define ([
             prop: 'remark',
             maxlen: 55
         },
+        // Employee profile - status
+        'ePstatus': {
+            name: 'ePstatus',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Status',
+            prop: 'priv',
+            maxlen: 10
+        },
+        // Employee profile - statusSince
+        'ePstatusSince': {
+            name: 'ePstatusSince',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Since',
+            prop: 'effective',
+            maxlen: 30
+        },
 
         // change password
         'newPass': {
@@ -176,29 +194,29 @@ define ([
             'preamble': null,
             'aclProfile': 'passerby',
             'entriesRead': [entries.ePfullname, entries.ePnick,
-                 entries.ePsec_id, entries.ePemail, entries.ePremark],
+                entries.ePsec_id, entries.ePemail, entries.ePremark,
+                entries.ePstatus, entries.ePstatusSince],
             'entriesWrite': [],
-            'hook': function () { return currentUser('obj'); },
+            'hook': empLib.getEmployeeObject,
             'miniMenu': {
-                entries: ['empProfileEdit'],
+                entries: ['empProfileEditRemark'],
                 back: ['Back', 'mainEmpl']
             }
         });
 
-        target.push('empProfileEdit', {
-            'name': 'empProfileEdit',
+        target.push('empProfileEditRemark', {
+            'name': 'empProfileEditRemark',
             'type': 'dform',
-            'menuText': 'Edit',
+            'menuText': 'Edit remark',
             'title': 'Edit remark',
             'preamble': null,
             'aclProfile': 'admin',
-            'entriesRead': [entries.ePfullname, entries.ePnick,
-                entries.ePsec_id, entries.ePemail],
+            'entriesRead': [entries.ePnick, entries.ePfullname],
             'entriesWrite': [entries.ePremark],
             'hook': function () { return currentUser('obj'); },
             'miniMenu': {
                 entries: ['empProfileUpdate'],
-                back: ['Back to employee menu', 'mainEmpl']
+                back: ['Back', 'empProfile']
             }
         });
 
@@ -248,23 +266,6 @@ define ([
             }
         });
 
-        target.push('dispEmployee', {
-            'name': 'dispEmployee',
-            'type': 'dform',
-            'menuText': 'Employee profile',
-            'title': 'Employee profile',
-            'preamble': null,
-            'aclProfile': 'admin',
-            'entriesRead': [entries.ePfullname, entries.ePnick, entries.ePsec_id,
-                entries.ePemail, entries.ePremark],
-            'entriesWrite': [],
-            'hook': empLib.getEmployeeObject,
-            'miniMenu': {
-                entries: [],
-                back: ['To leave this page, press ENTER or click the Submit button', 'mainEmpl']
-            }
-        });
-  
         target.push('searchEmployee', {
             'name': 'searchEmployee',
             'type': 'dform',
