@@ -56,10 +56,49 @@ define ([
 
     var 
         // employee object storage
-        employeeObject,
+        employeeObject = Object.create(prototypes.empProfile),
 
-        // method for setting the stored employee object
-        setEmployeeObject = function (emp) { $.extend(Object.create(prototypes.empProfile), emp); },
+        // method for accessing the stored employee object
+        getEmployeeObject = function () { return employeeObject; },
+
+        myProfile = function () {
+            if (employeeObject.effective !== null) {
+                target.pull('empProfile').start();
+            } else {
+                loadEmpProfile(currentUser('obj').eid);
+            }
+        },
+
+        loadEmpProfile = function (eid) {
+            var rest = {
+                    "method": 'GET',
+                    "path": 'employee/eid/' + eid + '/full'
+                },
+                // success callback
+                sc = function (st) {
+                    if (st.code === 'DISPATCH_EMPLOYEE_PROFILE_FULL') {
+                        console.log("Payload is", st.payload);
+                        var effective = st.payload.privhistory.effective;
+                        effective = effective.substr(0, effective.indexOf(" "));
+                        employeeObject = $.extend(
+                            Object.create(prototypes.empProfile), {
+                                'eid': st.payload.emp.eid,
+                                'nick': st.payload.emp.nick,
+                                'fullname': st.payload.emp.fullname,
+                                'email': st.payload.emp.email,
+                                'remark': st.payload.emp.remark,
+                                'sec_id': st.payload.emp.sec_id,
+                                'priv': st.payload.privhistory.priv,
+                                'effective': effective
+                            }
+                        );
+                        currentUser('obj', employeeObject);
+                        target.pull('empProfile').start();
+                    }
+                },
+                fc = null;
+            ajax(rest, sc, fc);
+        },
 
         // "search employee" method
         searchEmp = function (obj) {
@@ -105,7 +144,7 @@ define ([
                     $('#result').html("Created new employee " + st.payload.nick);
                     employeeObject = st.payload;
                     setEmployeeObject(employeeObject);
-                    target.pull('dispEmployee').start();
+                    target.pull('empProfile').start();
                 },
                 // failure callback
                 fc = null;
@@ -194,8 +233,7 @@ define ([
 	// that differs between the two targets
         //
         epuGen = function (afterTarget, emp) {
-            var protoEmp = Object.create(prototypes.empProfile),
-                t = target.pull(afterTarget);
+            var protoEmp = Object.create(prototypes.empProfile);
             console.log("Entering epuGen with target " + afterTarget + " and object", emp);
             $.extend(protoEmp, emp);
             var rest = {
@@ -212,10 +250,10 @@ define ([
                         // this is an employee profile update
                         $("#result").html("Employee profile updated");
                     }
-                    $.extend(protoEmp, st.payload);
-                    currentUser("obj", protoEmp);
                     console.log("Saved new employee object to database: ", protoEmp);
-                    t.start();
+                    $.extend(employeeObject, st.payload);
+                    console.log("Profile object is", employeeObject);
+                    target.pull(afterTarget).start();
                 },
                 fc = function (st) {
                     console.log("Failure callback received argument", st);
@@ -227,10 +265,11 @@ define ([
     // here is where we define methods implementing the various
     // employee-related actions (see daction-start.js)
     return {
-        getEmployeeObject: function () { return employeeObject; },
-        setEmployeeObject: setEmployeeObject,
+        getEmployeeObject: getEmployeeObject,
         mainEmpl: function (emp) { epuGen('mainEmpl', emp); },
-        empProfile: function (emp) { epuGen('empProfile', emp); },
+        myProfile: myProfile,
+        loadEmpProfile: loadEmpProfile,
+        empProfileUpdate: function (emp) { epuGen('empProfile', emp); },
         passChangePending: function (emp) {
             employeeObject = emp;
             target.pull('confirmPassword').start();
